<?php
/**
 * implementiert die Informationsseite über Netzwerk, Versionen, Datum, Uptime und Line Interfaces
 * @author Miguel Palmer <mp@beronet.com>
 */

class Info {

	private $_is_sbc_vm = false;

 /**
 	* Constructor
 	*/
  function __construct($m, $get = array(), $post = array(), $session = array()) {
	}

	/**
	 * Funktion display erzeugt den Inhalt von der HTML-Seite
	 * @return string HTML Inhalt
	 */
	public function display() {
		// default
		$display_by_type = array(
			'0' => '_displaySbcInfo',
			'1' => '_displaySbcvmInfo'
		);

		// init
    $name = "INFO_TITLE_DIS";
		include('./includes/header.php');

    include('/usr/fallback/beroConf.php');
    $bc = new beroConf('root');

		include_once('./misc/database.php');
		$ba = new beroAri();

		// get type
		$this->_is_sbc_vm = $ba->get('is_sbc_vm') ? '1' : '0';

		// load info
		$info = Helper::getInfo($bc, $ba, null, $this->_is_sbc_vm);

		// display the info
		$method = $display_by_type[$this->_is_sbc_vm];
		$ret .= $this->$method($info);
		return $ret;
	}

	/* [PRIVATE METHOD] */
	private function _displayNetworkTable($ifaces, $nameservers = array()) {
		// rows title conversion
		$rows_title = array(
			'macaddr'	=> INFO_MAC_ADDRESS_DIS,
			'ipaddr'	=> INFO_IP_ADDRESS_DIS,
			'netmask'	=> INFO_NETMASK_DIS,
			'gateway'	=> INFO_GATEWAY_DIS,
		);

		$rows_dns_title = array(
			'0' => NETWORK_PRIMARY_NAME_SERVER_DIS,
			'1' => NETWORK_SECONDARY_NAME_SERVER_DIS,
		);

		// build table
		$table =	  "<table class='table table-striped table-bordered' style='width:36% !important; margin:auto; margin-bottom: 25px;'>\n"
				. "\t<tr><th colspan='2'>".INFO_NET_CONFIGURATION_DIS."</th></tr>\n";

		foreach (array_keys($ifaces) as $iface) {
			$table .=	  "\t<tr></tr>\n"
					. "\t<tr><th colspan='2'>". strtoupper($iface) . ($this->_is_sbc_vm && $iface == 'lan' ? '/VPN' : '') ."</th></tr>\n";
			foreach($ifaces[$iface] as $param => $value) {
				$table .= "\t<tr><td nowrap>{$rows_title[$param]}</td><td>$value</td></tr>\n";
			}
		}

		foreach ($nameservers as $id => $value) {
			$table .= "\t<tr><td>{$rows_dns_title[$id]}</td><td>$value</td></tr>\n";
		}

		// return table
		$table .= "</table>\n";
		return $table;
	}

	private function _displayInfoTable($name, $rows, $two_columns = false) {
		$table = "<table class='table table-striped table-bordered' style='width:36% !important; margin:auto; margin-bottom: 25px;'>\n";

		// display two columns
		if ($two_columns) {
			$table .= "\t<tr><th colspan='2'>$name</th></tr>\n";
			foreach ($rows as $key_column => $value_column) {
				$table .= "\t<tr><td>$key_column</td><td>$value_column</td></tr>\n";
			}
		}
		// display one column
		else {
			$table .=	  "\t<tr><th>$name</th></tr>\n"
					. "\t<tr><td nowrap>$rows</td></tr>\n";
		}

		$table .= "</table>\n";
		return $table;
	}

	private function _displaySbcInfo($info) {
		// serial
		$html = $this->_displayInfoTable(INFO_SERIAL_NUMBER_DIS, $info['serial']);

		// versions
		$versions = array(
			'appfs' 		=> $info['appfs'],
			'rootfs'		=> $info['rootfs'],
			'mtdblock'		=> $info['mtdblock'],
			'FGPA'			=> $info['fgpa'],
			'MSP'			=> $info['msp_fw'],
			INFO_HW_REVISION_DIS	=> $info['hw_revision'],
			'PHP'			=> $info['php'],
		);
		$html .= $this->_displayInfoTable(INFO_VERSIONS_DIS, $versions, true);

		// Netzwerkkonfiguration
		$html .= $this->_displayNetworkTable($info['network']['iface'], $info['network']['provided']['nameserver']);

		// date
		$html .= $this->_displayInfoTable(INFO_DATE_TIME_DIS, $info['date']);

		//Anzeige der installierten LI Module
		if (!empty($info['lif'])) {
			$html .=  "<table class='table table-striped table-bordered' style='width:36% !important; margin:auto; margin-bottom: 25px;'>\n"
							. "\t<tr><th>".INFO_LINE_INTERFACES_DIS."</th></tr>\n";
			foreach ($info['lif'] as $lif) {
				$html .= "\t<tr><td nowrap>$lif</td></tr>\n";
			}
			$html .= "</table>\n";
		}

		// uptime
		$uptime = array(
			'System'=> $info['system_uptime'],
			'ISGW'	=> $info['isgw_uptime'],
		);
		$html .= $this->_displayInfoTable(INFO_UPTIME_DIS, $uptime, true);

		return $html;
	}

	private function _displaySbcvmInfo($info) {
		// serial
		$html = $this->_displayInfoTable(INFO_SERIAL_NUMBER_DIS, $info['serial']);

		// versions
		$versions = array(
			'Package'	=> $info['package'],
			'PHP' 		=> $info['php'],
		);
		$html .= $this->_displayInfoTable(INFO_VERSIONS_DIS, $versions, true);

		// network configuration
		$html .= $this->_displayNetworkTable($info['network']);

		// date
		$html .= $this->_displayInfoTable(INFO_DATE_TIME_DIS, $info['date']);

		// uptime
		$uptime = array(
			'System'=> $info['system_uptime'],
			'ISGW'	=> $info['isgw_uptime'],
		);
		$html .= $this->_displayInfoTable(INFO_UPTIME_DIS, $uptime, true);

		return $html;
	}
}
?>
